@@ -66,12 +66,14 @@
 #define BUGZILLA_EMAIL                  "X-GNOME-Bugzilla-Email"
 #define BUGZILLA_VERSION                "X-GNOME-Bugzilla-Version"
 #define BUGZILLA_OTHER_BINARIES         "X-Gnome-Bugzilla-OtherBinaries"
+#define BUGZILLA_EXTRA_INFO_SCRIPT      "X-GNOME-Bugzilla-ExtraInfoScript"
 
 #define BA_BUGZILLA_BUGZILLA            "bugzilla:bugzilla"
 #define BA_BUGZILLA_PRODUCT             "bugzilla:product"
 #define BA_BUGZILLA_COMPONENT           "bugzilla:component"
 #define BA_BUGZILLA_VERSION             "bugzilla:version"
 #define BA_BUGZILLA_OTHER_BINARIES      "bugzilla:other_binaries"
+#define BA_BUGZILLA_EXTRA_INFO_SCRIPT   "bugzilla:extra_info_script"
 
 static void
 add_bugzilla_application (GHashTable *hash, 
@@ -84,7 +86,8 @@ add_bugzilla_application (GHashTable *hash,
 			  const char *version, 
 			  const char *icon,
 			  const char *program,
-			  const char *other_programs)
+			  const char *other_programs,
+			  const char *extra_info_script)
 {
 	BugzillaApplication *app;
 	char **programv;
@@ -92,54 +95,23 @@ add_bugzilla_application (GHashTable *hash,
 
 	app = g_new0 (BugzillaApplication, 1);
 	
-	app->name        = g_strdup (name);
-	app->cname       = g_strdup (cname);
-	app->comment     = g_strdup (comment);
-	app->bugzilla    = g_strdup (bugzilla);
-	app->product     = g_strdup (product);
-	app->component   = g_strdup (component);
-	app->version     = g_strdup (version);
+	app->name              = g_strdup (name);
+	app->cname             = g_strdup (cname);
+	app->comment           = g_strdup (comment);
+	app->icon	       = g_strdup (icon);
+	app->bugzilla          = g_strdup (bugzilla);
+	app->product           = g_strdup (product);
+	app->component         = g_strdup (component);
+	app->version           = g_strdup (version);
+	app->extra_info_script = g_strdup (extra_info_script);
 
-	if (icon) {
-		if (g_path_is_absolute (icon)) {
-			app->pixbuf = gdk_pixbuf_new_from_file_at_size (icon, 48, 48, NULL);
-		}
-		if (app->pixbuf == NULL) {
-			app->pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-								icon, 48, 0, NULL);
-		}
-		if (app->pixbuf == NULL && strrchr (icon, '.') != NULL) {
-			char *name;
-			name = g_strndup (icon, strlen (icon) - strlen (strrchr (icon, '.')));
-			app->pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-								name, 48, 0, NULL);
-			g_free (name);
-		}
-	
-		if (app->pixbuf == NULL) {
-			char *filename;
-			filename = g_strdup_printf (BUDDY_ICONDIR"/pixmaps/%s", icon);
-			app->pixbuf = gdk_pixbuf_new_from_file_at_size (filename, 48, 48, NULL);
-			g_free (filename);
-		}
-	}
-
-	if (app->pixbuf == NULL) {
-		g_warning (_("Couldn't load icon for %s"), app->name);
-	}
-	
 	if (program) {
 		g_shell_parse_argv (program, &i, &programv, NULL);
 		if (programv[0]) {
 			char *s;
 			s = strrchr (programv[0], G_DIR_SEPARATOR);
 			s = s ? s+1 : programv[0];
-			if (g_hash_table_lookup (hash, s) == NULL) {
-				g_hash_table_insert (hash, g_strdup (s), app);
-			} else {
-				g_free (app);
-				return;
-			}
+			g_hash_table_insert (hash, g_strdup (s), app);
 		} else {
 			g_free (app);
 			return;
@@ -151,14 +123,30 @@ add_bugzilla_application (GHashTable *hash,
 	if (other_programs) {
 		programv = g_strsplit (other_programs, ";", -1);
 		for (i=0; programv[i]; i++) {
-			if (g_hash_table_lookup (hash, programv[i]) == NULL) {
-				g_hash_table_insert (hash, g_strdup (programv[i]), app);
-			}
+			g_hash_table_insert (hash, g_strdup (programv[i]), app);
 		}
 		g_strfreev (programv);
 	}
 }
 
+static void
+application_free (BugzillaApplication *app)
+{
+	g_free (app->name);
+	g_free (app->cname);
+	g_free (app->comment);
+	g_free (app->icon);
+	g_free (app->bugzilla);
+	g_free (app->product);
+	g_free (app->component);
+	g_free (app->version);
+	g_free (app->extra_info_script);
+	g_free (app);
+}
+
+
+	
+
 static const GSList *
 get_i18n_slist (void)
 {
@@ -231,7 +219,8 @@ NULL)) {
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_VERSION, NULL),
 			bonobo_server_info_prop_lookup (info, "panel:icon", NULL),
 			NULL,
-			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_OTHER_BINARIES, NULL));
+			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_OTHER_BINARIES, NULL),
+			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_EXTRA_INFO_SCRIPT, NULL));
 		
 		g_free (name);
 	}
@@ -359,7 +348,7 @@ load_applications (void)
 	const char     *prev_name = NULL;
 	GError	       *error = NULL;
 
-	GHashTable *program_to_application = g_hash_table_new (g_str_hash, g_str_equal);
+	GHashTable *program_to_application = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) application_free);
 
 	all_applications = get_all_applications ();
 	for (l = all_applications; l; l = l->next) {
@@ -374,6 +363,7 @@ load_applications (void)
 		char *icon;
 		char *exec;
 		char *other_binaries;
+		char *extra_info_script;
 		GMenuTreeEntry *entry = l->data;
 
 		if (g_main_context_pending (NULL)) {
@@ -414,6 +404,7 @@ load_applications (void)
 		icon = g_key_file_get_string (key_file, DESKTOP_ENTRY, DESKTOP_ICON, NULL);
 		exec = g_key_file_get_string (key_file, DESKTOP_ENTRY, DESKTOP_EXEC, NULL);
 		other_binaries = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_OTHER_BINARIES, NULL);
+		extra_info_script = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_EXTRA_INFO_SCRIPT, NULL);
 
 		add_bugzilla_application (program_to_application,
 					  name,
@@ -425,7 +416,8 @@ load_applications (void)
 					  version,
 					  icon,
 					  exec,
-					  other_binaries);
+					  other_binaries,
+					  extra_info_script);
 		g_free (name);
 		g_free (cname);
 		g_free (comment);
@@ -436,6 +428,7 @@ load_applications (void)
 		g_free (icon);
 		g_free (exec);
 		g_free (other_binaries);
+		g_free (extra_info_script);
 		prev_name = gmenu_tree_entry_get_name (entry);
 		g_key_file_free (key_file);	
 		gmenu_tree_item_unref (entry);
@@ -467,7 +460,7 @@ bugzilla_parse_response (SoupMessage *msg, GError **err)
 	long bugid;
 	int debug = 0;
 
-	g_return_if_fail (err == NULL || *err == NULL);
+	g_return_val_if_fail ((err == NULL || *err == NULL), -1);
 
 	if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
 		g_set_error (err, BUGZILLA_ERROR, BUGZILLA_ERROR_RECV_BAD_STATUS, 
@@ -548,7 +541,7 @@ parse_error:
 }
 
 SoupXmlrpcMessage*
-bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version,
+bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gnome_version,
 		        const char *username, const char *title, const char *text,
 		        GladeXML *xml, GError **err)
 {
@@ -557,7 +550,6 @@ bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_versio
 	char *distro;
 	char *comment;
 	char *user_agent;
-	int type;
 
 	g_return_val_if_fail (app != NULL, NULL);
 	g_return_val_if_fail (gnome_version != NULL, NULL);
@@ -614,14 +606,15 @@ bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_versio
 	soup_xmlrpc_message_write_string (message, username);
 	soup_xmlrpc_message_end_member (message);
 
-	soup_xmlrpc_message_start_member (message, "priority");
-	soup_xmlrpc_message_write_string (message, "High");
-	soup_xmlrpc_message_end_member (message);
-
-	soup_xmlrpc_message_start_member (message, "bug_severity");
-	soup_xmlrpc_message_write_string (message, "critical");
-	soup_xmlrpc_message_end_member (message);
+	if (type == BUG_TYPE_CRASH) {
+		soup_xmlrpc_message_start_member (message, "priority");
+		soup_xmlrpc_message_write_string (message, "High");
+		soup_xmlrpc_message_end_member (message);
 
+		soup_xmlrpc_message_start_member (message, "bug_severity");
+		soup_xmlrpc_message_write_string (message, "critical");
+		soup_xmlrpc_message_end_member (message);
+	}
 
 	soup_xmlrpc_message_start_member (message, "short_desc");
 	soup_xmlrpc_message_write_string (message, title); 
